@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Album::Pages;
 use strict;
 use warnings;
 
-my $VERSION = '1.06';
+our $VERSION = '1.07';
 
 =head1 NAME
 
@@ -372,7 +372,7 @@ sub ArchiveEdit {
 
         } elsif($cgiparams{doaction} eq 'Move') {
             $cgiparams{'pageid'} ||= 1;
-            $dbi->DoQuery('MovePhotos',$cgiparams{'pageid'},{ids=>join(',',@ids)});
+            $dbi->DoQuery('MovePhotos',{ids=>join(',',@ids)},$cgiparams{'pageid'})  if(@ids);
         }
     }
 
@@ -437,12 +437,17 @@ sub Edit {
     $tvars{data}->{ddpages}  = PageSelect(undef,1,'parent',$tvars{data}->{pageid});
 
     # check we have an accessible directory to store photos
-    my $dir = "$settings{webdir}/$tvars{data}->{path}";
-    $tvars{data}->{exists}     = -e "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
-    $tvars{data}->{directory}  = -d "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
-    $tvars{data}->{readable}   = -r "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
-    $tvars{data}->{writeable}  = -w "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
-    $tvars{data}->{executable} = -x "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
+    if($tvars{data}->{path}) {
+        $settings{webdir} ||= '';
+        my $dir = "$settings{webdir}/$tvars{data}->{path}";
+        $tvars{data}->{exists}     = -e "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
+        $tvars{data}->{directory}  = -d "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
+        $tvars{data}->{readable}   = -r "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
+        $tvars{data}->{writeable}  = -w "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
+        $tvars{data}->{executable} = -x "$settings{webdir}/$tvars{data}->{path}" ? 1 : 0;
+    } else {
+        $tvars{data}->{$_} = 0  for(qw(exists directory readable writeable executable));    
+    }
 
     # default image sizes
     $tvars{dimensions}->{photowidth}  = $settings{maxphotowidth}  || MaxPhotoWidth;
@@ -504,7 +509,7 @@ sub Save {
             $dbi->DoQuery('DeletePhoto',$_->{photoid});
         }
     } else {
-        $dbi->DoQuery('MovePhotos',{ids => join(',',@ids)},1);
+        $dbi->DoQuery('MovePhotos',{ids => join(',',@ids)},1)   if(@ids);
     }
 
     # get fresh list
@@ -568,10 +573,12 @@ sub Selection {
 
 sub PageSelect {
     my ($opt,$blank,$name,@ignore) = @_;
+    my (@list,%ignore);
+
     $name ||= 'pageid';
+    %ignore = map {$_=>1} grep {$_} @ignore;
+
     my @rs = $dbi->GetQuery('hash','AdminPages');
-    my %ignore = map {$_=>1} @ignore;
-    my @list;
     for my $rec (@rs) {
         next    if($ignore{$rec->{pageid}});
         push @list, {id=>$rec->{pageid},value=>"$rec->{title}"};
